@@ -18,21 +18,26 @@
  */
 
 #include <config.h>
-#include <panel-applet-gconf.h>
 
-#include <libgnomeui/gnome-help.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include <glib-object.h>
-#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkaboutdialog.h>
+#include <libgnomeui/gnome-help.h>
+#include <panel-applet-gconf.h>
 #include <X11/XKBlib.h>
 #define XK_MISCELLANY
 #define XK_XKB_KEYS
 #include <X11/keysymdef.h>
 #include "applet.h"
 
-int xkb_base_event_type = 0;
+static int xkb_base_event_type = 0;
 
-GtkIconSize icon_size_spec;
+static GtkIconSize icon_size_spec;
 
 #define ALT_GRAPH_LED_MASK (0x10)
 
@@ -117,9 +122,8 @@ about_cb (BonoboUIComponent          *uic,
 	  AccessxStatusApplet        *sapplet,
 	  const gchar                *verbname)
 {
-	GdkPixbuf	 *pixbuf;
 	GError		 *error = NULL;
-	gchar		 *file;
+	gchar		 *file = NULL;
         
         static const gchar *authors [] = {
 		"Calum Benson <calum.benson@sun.com>",
@@ -142,29 +146,24 @@ about_cb (BonoboUIComponent          *uic,
 		gtk_window_present (GTK_WINDOW (sapplet->about_dialog));
 		return;
 	}
-        
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-					  "accessx-status-applet/ax-applet.png", 
-					  FALSE, NULL);
-	pixbuf = gdk_pixbuf_new_from_file (file, &error);
-	g_free (file);
-	
+
 	if (error) {
 		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
 		g_error_free (error);
 	}
 	
-        sapplet->about_dialog = gnome_about_new (_("AccessX Status"), VERSION,
-						 _("Copyright (C) 2003 Sun Microsystems"),
-						 _("Shows the state of AccessX features such as latched modifiers"),
-						 authors,
-						 documenters,
-						 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-						 pixbuf);
-		
-	if (pixbuf)
-		gdk_pixbuf_unref (pixbuf);
-			
+	sapplet->about_dialog = gtk_about_dialog_new();
+	g_object_set (sapplet->about_dialog,
+		      "name", _("AccessX Status"),
+		      "version", VERSION,
+		      "comments", _("Shows the state of AccessX features such as latched modifiers"),
+		      "copyright", _("Copyright (C) 2003 Sun Microsystems"),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator-credits", (strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL),
+		      "logo-icon-name", "ax-applet",
+		      NULL);
+		      
 	gtk_window_set_wmclass (GTK_WINDOW (sapplet->about_dialog), "accessx status", "AccessX Status");
 	gtk_window_set_screen (GTK_WINDOW (sapplet->about_dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
@@ -195,7 +194,7 @@ help_cb (BonoboUIComponent   *uic,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
-						_("There was an error launching the help viewer : %s"), 
+						_("There was an error launching the help viewer: %s"), 
 						error->message);
 
 		g_signal_connect (G_OBJECT (dialog),
@@ -234,7 +233,7 @@ dialog_cb (BonoboUIComponent *component,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
-						_("There was an error launching the keyboard capplet : %s"), 
+						_("There was an error launching the keyboard capplet: %s"), 
 						error->message);
 
 		g_signal_connect (G_OBJECT (dialog),
@@ -258,7 +257,7 @@ static const BonoboUIVerb accessx_status_applet_menu_verbs [] = {
 	BONOBO_UI_VERB_END
 };
 
-XkbDescPtr 
+static XkbDescPtr 
 accessx_status_applet_get_xkb_desc (AccessxStatusApplet *sapplet)
 {
 	Display *display;
@@ -285,7 +284,7 @@ accessx_status_applet_get_xkb_desc (AccessxStatusApplet *sapplet)
 	return sapplet->xkb;
 }
 
-gboolean
+static gboolean
 accessx_status_applet_xkb_select (AccessxStatusApplet *sapplet)
 {
 	int opcode_rtn, error_rtn;
@@ -911,8 +910,11 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 		do {
 			char *filename, *tmp;
 			GtkIconSource *source = gtk_icon_source_new ();
-			tmp = g_strdup_printf (GNOME_PIXMAPSDIR"accessx-status-applet/%s", stock_icons[i].name);
-			filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+			tmp = g_strdup_printf (GNOME_PIXMAPSDIR
+					"/accessx-status-applet/%s",
+					stock_icons[i].name);
+			filename = gnome_program_locate_file (NULL,
+					GNOME_FILE_DOMAIN_PIXMAP, 
 					  tmp, 
 					  FALSE, NULL);
 			g_free (tmp);
@@ -1182,31 +1184,46 @@ accessx_status_applet_resize (GtkWidget *widget, int size, gpointer user_data)
 }
 
 static void
-accessx_status_applet_background (PanelApplet *a, PanelAppletBackgroundType type,
-				  GdkColor *color, GdkPixmap *pixmap, gpointer user_data)
+accessx_status_applet_background (PanelApplet *a,
+				  PanelAppletBackgroundType type,
+				  GdkColor *color,
+				  GdkPixmap *pixmap,
+				  gpointer user_data)
 {
 	AccessxStatusApplet *sapplet = user_data;
-	GtkRcStyle *rc_style = gtk_rc_style_new ();
 
-	switch (type) {
-	case PANEL_PIXMAP_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
+        GtkRcStyle *rc_style;
+        GtkStyle *style;
 
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg (GTK_WIDGET (sapplet->applet), GTK_STATE_NORMAL, color);
-		break;
+        /* reset style */
+        gtk_widget_set_style (GTK_WIDGET (sapplet->applet), NULL);
+        rc_style = gtk_rc_style_new ();
+        gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
+        gtk_rc_style_unref (rc_style);
 
-	case PANEL_NO_BACKGROUND:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
+        switch (type) {
+                case PANEL_COLOR_BACKGROUND:
+                        gtk_widget_modify_bg (GTK_WIDGET (sapplet->applet),
+                                        GTK_STATE_NORMAL, color);
+                        break;
 
-	default:
-		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-		break;
-	}
+                case PANEL_PIXMAP_BACKGROUND:
+                        style = gtk_style_copy (
+                                        GTK_WIDGET (sapplet->applet)->style);
+                        if (style->bg_pixmap[GTK_STATE_NORMAL])
+                                g_object_unref
+                                        (style->bg_pixmap[GTK_STATE_NORMAL]);
+                        style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
+                                (pixmap);
+                        gtk_widget_set_style (GTK_WIDGET (sapplet->applet),
+                                        style);
+                        g_object_unref (style);
+                        break;
 
-	gtk_rc_style_unref (rc_style);
+                case PANEL_NO_BACKGROUND:
+                default:
+                        break;
+        }
 }
 
 static gboolean
