@@ -1,4 +1,4 @@
-/* $Id: weather-metar.c,v 1.8 2005/01/24 14:01:27 davyd Exp $ */
+/* $Id: weather-metar.c,v 1.9 2005/07/06 14:19:49 davyd Exp $ */
 
 /*
  * Code for parsing METAR weather observations
@@ -33,7 +33,7 @@ static time_t make_time (gint utcDate, gint utcHour, gint utcMin)
     const time_t now = time(NULL);
     struct tm tm;
 
-    gmtime_r (&now, &tm);
+    localtime_r (&now, &tm);
 
     /* If last reading took place just before midnight UTC on the first, adjust the
      * date downward.  This ASSUMES that the reading won't be more than 24 hrs old! */
