@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.107.2.1 2005/03/30 06:17:41 ryanl Exp $ */
+/* $Id: weather.c,v 1.110 2005/06/09 08:42:59 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -781,82 +781,6 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     return TRUE;
 }
 
-void weather_info_config_write (WeatherInfo *info)
-{
-    g_return_if_fail(info != NULL);
-
-    gnome_config_set_bool("valid", info->valid);
-    gnome_config_set_int("update", info->update);
-    gnome_config_set_int("sky", (gint)info->sky);
-    gnome_config_set_bool("cond_significant", info->cond.significant);
-    gnome_config_set_int("cond_phenomenon", (gint)info->cond.phenomenon);
-    gnome_config_set_int("cond_qualifier", (gint)info->cond.qualifier);
-    gnome_config_set_float("temp", info->temp);
-    gnome_config_set_float("dew", info->dew);
-    gnome_config_set_int("wind", (gint)info->wind);
-    gnome_config_set_int("windspeed", info->windspeed);
-    gnome_config_set_float("pressure", info->pressure);
-    gnome_config_set_float("visibility", info->visibility);
-    if (info->forecast)
-        gnome_config_set_string("forecast", info->forecast);
-    else
-        gnome_config_set_string("forecast", "");
-    /* info->radar = NULL; */
-}
-
-WeatherInfo *weather_info_config_read (PanelApplet *applet)
-{
-    WeatherInfo *info = g_new(WeatherInfo, 1);
-#if 0
-    info->valid = gnome_config_get_bool("valid=FALSE");
-    info->location = weather_location_config_read("location");
-    info->update = (WeatherUpdate)gnome_config_get_int("update=0");
-    info->sky = (WeatherSky)gnome_config_get_int("sky=0");
-    info->cond.significant = gnome_config_get_bool("cond_significant=FALSE");
-    info->cond.phenomenon = (WeatherConditionPhenomenon)gnome_config_get_int("cond_phenomenon=0");
-    info->cond.qualifier = (WeatherConditionQualifier)gnome_config_get_int("cond_qualifier=0");
-    info->temp = gnome_config_get_float("temp=0");
-    info->dew = gnome_config_get_float("dew=0");
-    info->wind = (WeatherWindDirection)gnome_config_get_int("wind=0");
-    info->windspeed = gnome_config_get_int("windspeed=0");
-    info->pressure = gnome_config_get_float("pressure=0");
-    info->visibility = gnome_config_get_float("visibility=0");
-    info->forecast = gnome_config_get_string("forecast=None");
-    info->radar = NULL;
-#endif
-    info->valid = FALSE;
-    info->location = weather_location_config_read(applet);
-    info->update = (WeatherUpdate)0;
-    info->sky = -1;
-    info->cond.significant = FALSE;
-    info->cond.phenomenon = (WeatherConditionPhenomenon)0;
-    info->cond.qualifier = (WeatherConditionQualifier)0;
-    info->temp = -1000.0;
-    info->dew = -1000.0;
-    info->wind = -1;
-    info->windspeed = -1;
-    info->pressure = -1.0;
-    info->visibility = -1.0;
-    info->sunValid = FALSE;
-    info->sunrise = 0;
-    info->sunset = 0;
-    info->forecast = g_strdup ("None");
-    info->radar = NULL;  /* FIX */
-    info->requests_pending = FALSE;
-    info->metar_buffer = NULL;
-    info->iwin_buffer = NULL;
-
-    info->met_buffer = NULL;
-    info->bom_buffer = NULL;
-
-    info->met_handle = NULL;
-    info->iwin_handle = NULL;
-    info->met_handle = NULL;
-    info->bom_handle = NULL;
-
-    return info;
-}
-
 WeatherInfo *weather_info_clone (const WeatherInfo *info)
 {
     WeatherInfo *clone;
@@ -1153,7 +1077,13 @@ static const gchar *windspeed_string (gfloat knots, SpeedUnit to_unit)
             /* TRANSLATOR: This is the wind speed in meters per second */
             g_snprintf(buf, sizeof (buf), _("%.1f m/s"), WINDSPEED_KNOTS_TO_MS(knots));
             break;
-
+	case SPEED_UNIT_BFT:
+	    /* TRANSLATOR: This is the wind speed as a Beaufort force factor
+	     * (commonly used in nautical wind estimation).
+	     */
+	    g_snprintf (buf, sizeof (buf), _("Beaufort force %.1f"),
+				    WINDSPEED_KNOTS_TO_BFT (knots));
+	    break;
         case SPEED_UNIT_INVALID:
         case SPEED_UNIT_DEFAULT:
         default:
