@@ -29,8 +29,10 @@
 #include <glib-object.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkicontheme.h>
+#include <gtk/gtkmain.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkrange.h>
 #include <gtk/gtktooltips.h>
@@ -38,7 +40,8 @@
 
 #include <gconf/gconf-client.h>
 
-#include <libgnome/gnome-help.h>
+#include <libgnomeui/gnome-help.h>
+#include <libgnome/gnome-desktop-item.h>
 
 #include "applet.h"
 #include "keys.h"
@@ -60,6 +63,8 @@ static gboolean	gnome_volume_applet_button	(GtkWidget *widget,
 						 GdkEventButton *event);
 static gboolean	gnome_volume_applet_key		(GtkWidget *widget,
 						 GdkEventKey *event);
+static gdouble  gnome_volume_applet_get_volume  (GstMixer *mixer, 
+						 GstMixerTrack *track);
 
 static void	gnome_volume_applet_background	(PanelApplet *panel_applet,
 						 PanelAppletBackgroundType type,
@@ -135,47 +140,6 @@ gnome_volume_applet_get_type (void)
   return gnome_volume_applet_type;
 }
 
-/*
- * Hi, I'm slow.
- */
-
-static inline void
-flip_byte (guchar *one, guchar *two)
-{
-  gint temp;
-
-  temp = *one;
-  *one = *two;
-  *two = temp;
-}
-
-static inline void
-flip_pixel (guchar *line, gint pixel, gint width, gint bpp)
-{
-  gint n;
-
-  for (n = 0; n < bpp; n++) {
-    flip_byte (&line[pixel * bpp + n], &line[(width - 1 - pixel) * bpp + n]);
-  }
-}
-
-static void
-flip (GdkPixbuf *pix)
-{
-  gint w = gdk_pixbuf_get_width (pix),
-       h = gdk_pixbuf_get_height (pix),
-       x, y, stride = gdk_pixbuf_get_rowstride (pix),
-       bpp = gdk_pixbuf_get_n_channels (pix);
-  guchar *data = gdk_pixbuf_get_pixels (pix);
-
-  for (y = 0; y < h; y++) {
-    for (x = 0; x < (w / 2); x++) {
-      flip_pixel (data, x, w, bpp);
-    }
-    data += stride;
-  }
-}
-
 static void
 init_pixbufs (GnomeVolumeApplet *applet)
 {
@@ -192,7 +156,11 @@ init_pixbufs (GnomeVolumeApplet *applet)
       	    0,
       	    NULL);
     if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
-      flip (pix[n].pixbuf);
+      GdkPixbuf *temp;
+
+      temp = gdk_pixbuf_flip (pix[n].pixbuf, TRUE);
+      g_object_unref (G_OBJECT (pix[n].pixbuf));
+      pix[n].pixbuf = temp;
     }
   }
 }
@@ -223,13 +191,12 @@ static void
 gnome_volume_applet_init (GnomeVolumeApplet *applet)
 {
   GtkWidget *image;
-  GtkTooltips *tooltips;
 
   applet->timeout = 0;
   applet->elements = NULL;
   applet->client = gconf_client_get_default ();
   applet->mixer = NULL;
-  applet->track = NULL;
+  applet->tracks = NULL;
   applet->lock = FALSE;
   applet->state = -1;
   applet->prefs = NULL;
@@ -249,8 +216,8 @@ gnome_volume_applet_init (GnomeVolumeApplet *applet)
   applet->pop = FALSE;
 
   /* tooltip over applet */
-  tooltips = gtk_tooltips_new ();
-  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),
+  applet->tooltips = gtk_tooltips_new ();
+  gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet),
 			_("Volume Control"), NULL);
 
   /* handle icon theme changes */
@@ -266,54 +233,92 @@ gnome_volume_applet_init (GnomeVolumeApplet *applet)
 			  PANEL_APPLET_EXPAND_MINOR);
 }
 
-static GstMixerTrack *
-select_track (GstElement *element,
-	      const char *active_track_name)
+/* Parse the list of tracks that are stored in GConf */
+
+static char **
+parse_track_list (const char *track_list)
+{
+  if (track_list)
+    return g_strsplit (track_list, ":", 0);
+  else
+    return NULL;
+}
+
+static GList *
+select_tracks (GstElement *element,
+	      const char *active_track_names,
+	      gboolean    reset_state)
 {
   const GList *tracks, *l;
-  GstMixerTrack *active_track;
+  GstMixerTrack *track_fallback;
+  GList *active_tracks;
+  char **active_track_name_list;
+
+  active_tracks = NULL;
+  track_fallback = NULL;
+  active_track_name_list = NULL;
+
+  if (reset_state) {
+    if (gst_element_set_state (element, GST_STATE_READY) != GST_STATE_SUCCESS)
+      return NULL;
+  }
 
-  gst_element_set_state (element, GST_STATE_READY);
   tracks = gst_mixer_list_tracks (GST_MIXER (element));
+  if (active_track_names)
+    active_track_name_list = parse_track_list (active_track_names);
 
-  active_track = NULL;
   for (l = tracks; l; l = l->next) {
     GstMixerTrack *track = l->data;
+    gint i;
 
     if (!track->num_channels)
       continue;
 
-    if (!active_track)
-      active_track = track;
+    if (!track_fallback)
+      track_fallback = track;
 
     if (GST_MIXER_TRACK_HAS_FLAG (track, GST_MIXER_TRACK_MASTER))
-      active_track = track;
+      track_fallback = track;
 
-    if (active_track_name && !strcmp (track->label, active_track_name)) {
-      active_track = track;
-      break;
+    if (active_track_name_list) {
+      for (i = 0; active_track_name_list[i] != NULL; i++) {
+	gchar *track_test = active_track_name_list[i];
+	
+	if (!strcmp (track_test, track->label))
+	  active_tracks = g_list_append (active_tracks, track);
+      }
     }
   }
 
-  if (!active_track)
-    gst_element_set_state (element, GST_STATE_NULL);
+  /* if the list had no matches and we've got a fallback track,
+   * then use it. */
 
-  return active_track;
+  if (!active_tracks && track_fallback)
+    active_tracks = g_list_append (active_tracks, track_fallback);
+    
+  if (!active_tracks && reset_state) {
+    gst_element_set_state (element, GST_STATE_NULL);
+  }
+
+  g_strfreev (active_track_name_list);
+  return active_tracks;
 }
 
 static gboolean
 select_element_and_track (GnomeVolumeApplet *applet,
 			  GList             *elements,
 			  const char        *active_element_name,
-			  const char        *active_track_name)
+			  const char        *active_track_names)
 {
-  GList *l;
   GstElement *active_element;
   GstMixerTrack *active_track;
+  GList *active_tracks, *l;
 
   applet->elements = elements;
 
   active_element = NULL;
+  active_tracks = NULL;
+
   if (active_element_name) {
     for (l = elements; l; l = l->next) {
       GstElement *element = l->data;
@@ -329,28 +334,27 @@ select_element_and_track (GnomeVolumeApplet *applet,
     }
   }
 
-  active_track = NULL;
   if (active_element)
-    active_track = select_track (active_element, active_track_name);
+    active_tracks = select_tracks (active_element, active_track_names, TRUE);
 
-  if (!active_track) {
+  if (!active_tracks) {
     active_element = NULL;
     for (l = elements; l; l = l->next) {
       GstElement *element = l->data;
 
-      if ((active_track = select_track (element, active_track_name))) {
+      if ((active_tracks = select_tracks (element, active_track_names, TRUE))) {
 	active_element = element;
 	break;
       }
     }
   }
-
+  
   if (!active_element)
     return FALSE;
 
   applet->mixer = g_object_ref (active_element);
-  applet->track = g_object_ref (active_track);
-  g_assert (applet->track->num_channels != 0);
+  applet->tracks = active_tracks;
+  g_list_foreach (applet->tracks, (GFunc) g_object_ref, NULL);
 
   return TRUE;
 }
@@ -359,7 +363,6 @@ gboolean
 gnome_volume_applet_setup (GnomeVolumeApplet *applet,
 			   GList *elements)
 {
-  GConfValue *value;
   GtkObject *adj;
   gint page;
   BonoboUIComponent *component;
@@ -374,6 +377,8 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   gchar *key;
   gchar *active_element_name;
   gchar *active_track_name;
+  GstMixerTrack *first_track;
+  gboolean res;
 
   active_element_name = panel_applet_gconf_get_string (PANEL_APPLET (applet),
 						       GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT,
@@ -383,40 +388,35 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
 						     GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK,
 						     NULL);
 
-  if (!select_element_and_track (applet, elements, active_element_name, active_track_name)) {
-    GtkWidget *dialog;
-
-    g_free (active_element_name);
-    g_free (active_track_name);
-
-    dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
-				     GTK_BUTTONS_CLOSE,
-				     _("No volume control elements and/or devices found."));
-    gtk_widget_show (dialog);
-    gtk_dialog_run (GTK_DIALOG (dialog));
-    gtk_widget_destroy (dialog);
-
-    return FALSE;
-  }
-
+  res = select_element_and_track (applet, elements, active_element_name,
+				  active_track_name);
   g_free (active_element_name);
   g_free (active_track_name);
 
-  /* tell the dock */
-  page = (applet->track->max_volume - applet->track->min_volume) / 10;
-  adj = gtk_adjustment_new (0, applet->track->min_volume,
-			    applet->track->max_volume,
-			    (page / 5 > 0) ? page / 5 : 1,
-			    page, 0);
+  if (res) {
+    first_track = g_list_first (applet->tracks)->data;
+
+    /* tell the dock */
+    adj = gtk_adjustment_new (50, 0, 100, 2, 5, 0);
+    gtk_adjustment_set_value (GTK_ADJUSTMENT (adj), 
+			      gnome_volume_applet_get_volume (applet->mixer, 
+							      first_track));
+  }
+
   gnome_volume_applet_orientation (PANEL_APPLET (applet),
 				   panel_applet_get_orient (PANEL_APPLET (applet)));
-  gnome_volume_applet_dock_change (applet->dock,
-				   GTK_ADJUSTMENT (adj));
-  g_signal_connect (adj, "value-changed",
-		    G_CALLBACK (cb_volume), applet);
+
+  if (res) {
+    gnome_volume_applet_dock_change (applet->dock,
+				     GTK_ADJUSTMENT (adj));
+    g_signal_connect (adj, "value-changed",
+		      G_CALLBACK (cb_volume), applet);
+  }
 
   gnome_volume_applet_refresh (applet, FALSE);
-  applet->timeout = g_timeout_add (100, cb_check, applet);
+  if (res) {
+    applet->timeout = g_timeout_add (100, cb_check, applet);
+  }
 
   /* menu - done here because bonobo is intialized now */
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet), 
@@ -426,21 +426,19 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
   component = panel_applet_get_popup_component (PANEL_APPLET (applet));
   g_signal_connect (component, "ui-event", G_CALLBACK (cb_ui_event), applet);
 
-  /* gconf */
-  key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
+  if (res) {
+    /* gconf */
+    key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
 				GNOME_VOLUME_APPLET_KEY_ACTIVE_ELEMENT);
-#if 0
-  gconf_client_add_dir (applet->client, key,
-			GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-#endif
-  gconf_client_notify_add (applet->client, key,
-			   cb_gconf, applet, NULL, NULL);
-  g_free (key);
-  key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
-                                GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK);
-  gconf_client_notify_add (applet->client, key,
-                           cb_gconf, applet, NULL, NULL);
-  g_free (key);
+    gconf_client_notify_add (applet->client, key,
+			     cb_gconf, applet, NULL, NULL);
+    g_free (key);
+    key = panel_applet_gconf_get_full_key (PANEL_APPLET (applet),
+				GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK);
+    gconf_client_notify_add (applet->client, key,
+			     cb_gconf, applet, NULL, NULL);
+    g_free (key);
+  }
 
   gtk_widget_show (GTK_WIDGET (applet));
 
@@ -469,9 +467,10 @@ gnome_volume_applet_dispose (GObject *object)
     applet->elements = NULL;
   }
 
-  if (applet->track) {
-    g_object_unref (G_OBJECT (applet->track));
-    applet->track = NULL;
+  if (applet->tracks) {
+    g_list_foreach (applet->tracks, (GFunc) g_object_unref, NULL);
+    g_list_free (applet->tracks);
+    applet->tracks = NULL;
   }
 
   if (applet->mixer) {
@@ -487,6 +486,33 @@ gnome_volume_applet_dispose (GObject *object)
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
+/*
+ * Show a dialog (once) when no mixer is available.
+ */
+
+static void
+show_no_mixer_dialog (GnomeVolumeApplet *applet)
+{
+  static gboolean shown = FALSE;
+  GtkWidget *dialog;
+
+  if (shown)
+    return;
+  shown = TRUE;
+
+  dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
+		GTK_BUTTONS_CLOSE, "%s\n\n%s",
+		_("The volume control did not find any elements and/or "
+		  "devices to control. This means either that you don't "
+		  "have the right GStreamer plugins installed, or that you "
+		  "don't have a sound card configured."),
+		_("You can remove the volume control from the panel by "
+		  "right-clicking the speaker icon on the panel and "
+		  "selecting \"Remove From Panel\" from the menu."));
+  gtk_widget_show (dialog);
+  g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+}
+
 /*
  * get position that the dock should get based on applet position.
  */
@@ -545,7 +571,7 @@ gnome_volume_applet_popup_dock (GnomeVolumeApplet *applet)
   gint x, y;
 
   /* show (before reposition, so size allocation is done) */
-  gtk_widget_show (GTK_WIDGET (applet->dock));
+  gtk_widget_show_all (GTK_WIDGET (applet->dock));
 
   /* reposition */
   gnome_volume_applet_get_dock_position (applet, &x, &y);
@@ -582,7 +608,7 @@ gnome_volume_applet_popdown_dock (GnomeVolumeApplet *applet)
   gtk_grab_remove (widget);
 
   /* hide */
-  gtk_widget_hide (GTK_WIDGET (applet->dock));
+  gtk_widget_hide_all (GTK_WIDGET (applet->dock));
 
   /* set menu item as active */
   gtk_widget_set_state (GTK_WIDGET (applet), GTK_STATE_NORMAL);
@@ -611,8 +637,11 @@ gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
   BonoboUIComponent *component;
   gboolean mute = applet->state & 1;
   GtkAdjustment *adj = gtk_range_get_adjustment (applet->dock->scale);
+  GList *tracks;
+
+  for (tracks = g_list_first (applet->tracks); tracks; tracks = tracks->next)
+    gst_mixer_set_mute (applet->mixer, tracks->data, !mute);
 
-  gst_mixer_set_mute (applet->mixer, applet->track, !mute);
   if (mute) {
     /* sync back actual volume */
     cb_volume (adj, applet);
@@ -636,11 +665,22 @@ gnome_volume_applet_toggle_mute (GnomeVolumeApplet *applet)
 static void
 gnome_volume_applet_run_mixer (GnomeVolumeApplet *applet)
 {
+  GnomeDesktopItem *ditem;
   GError *error = NULL;
 
-  gdk_spawn_command_line_on_screen (
-      gtk_widget_get_screen (GTK_WIDGET (applet)),
-      "gnome-volume-control", &error);
+  if ((ditem = gnome_desktop_item_new_from_basename ("gnome-volume-control.desktop", 0, NULL))) {
+    gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
+    gnome_desktop_item_launch_on_screen (ditem, NULL,
+	                                 GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE,
+					 gtk_widget_get_screen (GTK_WIDGET (applet)),
+					 -1, &error);
+    gnome_desktop_item_unref (ditem);
+  }
+  else {
+    gdk_spawn_command_line_on_screen (
+	      gtk_widget_get_screen (GTK_WIDGET (applet)),
+	      "gnome-volume-control", &error);
+  }
 
   if (error) {
     GtkWidget *dialog;
@@ -666,6 +706,11 @@ gnome_volume_applet_scroll (GtkWidget      *widget,
 {
   GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (widget);
 
+  if (!applet->mixer) {
+    show_no_mixer_dialog (applet);
+    return TRUE;
+  }
+
   if (event->type == GDK_SCROLL) {
     switch (event->direction) {
       case GDK_SCROLL_UP:
@@ -691,7 +736,10 @@ gnome_volume_applet_scroll (GtkWidget      *widget,
     }
   }
 
-  return GTK_WIDGET_CLASS (parent_class)->scroll_event (widget, event);
+  if (GTK_WIDGET_CLASS (parent_class)->scroll_event)
+    return GTK_WIDGET_CLASS (parent_class)->scroll_event (widget, event);
+  else
+    return FALSE;
 }
 
 static gboolean
@@ -709,10 +757,16 @@ gnome_volume_applet_button (GtkWidget      *widget,
       case 1:
         switch (event->type) {
           case GDK_BUTTON_PRESS:
-            gnome_volume_applet_pop_dock (applet);
+            if (!applet->mixer) {
+              show_no_mixer_dialog (applet);
+            } else {
+              gnome_volume_applet_pop_dock (applet);
+            }
             return TRUE;
           case GDK_2BUTTON_PRESS:
-            gnome_volume_applet_popdown_dock (applet);
+            if (applet->mixer) {
+              gnome_volume_applet_popdown_dock (applet);
+            }
             gnome_volume_applet_run_mixer (applet);
             return TRUE;
           default:
@@ -743,7 +797,9 @@ gnome_volume_applet_key (GtkWidget   *widget,
 {
   GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (widget);
 
-  switch (event->keyval) {
+  if (!applet->mixer) {
+    show_no_mixer_dialog (applet);
+  } else switch (event->keyval) {
     case GDK_KP_Enter:
     case GDK_ISO_Enter:
     case GDK_3270_Enter:
@@ -877,6 +933,58 @@ gnome_volume_applet_background (PanelApplet *_applet,
   }
 }
 
+/* 
+ * This needs to be here because not all tracks have the same volume range,
+ * so you can send this function the track and a new volume and it will be
+ * scaled according to the volume range of the track in question. 
+ */
+
+void
+gnome_volume_applet_adjust_volume (GstMixer *mixer,
+				   GstMixerTrack *track,
+				   int volume)
+{
+  int range = track->max_volume - track->min_volume;
+  float scale = ((float) range) / 100;
+  int *volumes, n;
+
+  volume *= scale;
+  volume += track->min_volume;
+
+  volumes = g_new (gint, track->num_channels);
+  for (n = 0; n < track->num_channels; n++)
+    volumes[n] = volume;
+  gst_mixer_set_volume (mixer, track, volumes);
+  g_free (volumes);
+}
+
+static gdouble
+gnome_volume_applet_get_volume (GstMixer *mixer,
+				GstMixerTrack *track)
+{
+  int range;
+  float scale;
+  int *volumes, n;
+  gdouble j;
+
+  if (!track || !mixer)
+    return -1;
+
+  range = track->max_volume - track->min_volume;
+  scale = ((float) range) / 100;
+  j = 0;
+
+  volumes = g_new (gint, track->num_channels);
+  gst_mixer_get_volume (mixer, track, volumes);
+
+  for (n = 0; n < track->num_channels; n++)
+    j += volumes[n];
+  g_free (volumes);
+  j /= track->num_channels;
+
+  return j / scale;
+}
+
 /*
  * Volume changed.
  */
@@ -886,17 +994,19 @@ cb_volume (GtkAdjustment *adj,
 	   gpointer data)
 {
   GnomeVolumeApplet *applet = data;
-  gint *volumes, n;
+  gint *volumes, n, v;
+  GList *iter;
 
   if (applet->lock)
     return;
   applet->lock = TRUE;
 
-  volumes = g_new (gint, applet->track->num_channels);
-  for (n = 0; n < applet->track->num_channels; n++)
-    volumes[n] = gtk_adjustment_get_value (adj);
-  gst_mixer_set_volume (applet->mixer, applet->track, volumes);
-  g_free (volumes);
+  v = gtk_adjustment_get_value (adj);
+
+  for (iter = g_list_first (applet->tracks); iter; iter = iter->next) {
+    GstMixerTrack *track = iter->data;
+    gnome_volume_applet_adjust_volume (applet->mixer, track, v);
+  }
 
   applet->lock = FALSE;
 }
@@ -913,45 +1023,78 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
 {
   BonoboUIComponent *component;
   GdkPixbuf *pixbuf;
-  gint n, *volumes, volume = 0, orig_vol;
+  gint n;
+  gdouble volume;
   gboolean mute;
+  gchar *tooltip_str;
+  GstMixerTrack *first_track;
+  GString *track_names;
+  GList *iter;
 
-  /* build-up phase */
-  if (!applet->track)
+  if (!applet->mixer) {
+    n = 0;
+    mute = FALSE;
+  } else if (!applet->tracks) {
     return;
+  } else {
+    /* only first track */
+    first_track = g_list_first (applet->tracks)->data;
+    volume = gnome_volume_applet_get_volume (applet->mixer, first_track);
+    mute = GST_MIXER_TRACK_HAS_FLAG (first_track,
+				     GST_MIXER_TRACK_MUTE);
+    if (volume == 0)
+      mute = TRUE;
 
-  volumes = g_new (gint, applet->track->num_channels);
-  gst_mixer_get_volume (applet->mixer, applet->track, volumes);
-  for (n = 0; n < applet->track->num_channels; n++)
-    volume += volumes[n];
-  g_free (volumes);
-  mute = GST_MIXER_TRACK_HAS_FLAG (applet->track,
-				   GST_MIXER_TRACK_MUTE);
-  if (volume == 0)
-    mute = TRUE;
-  orig_vol = volume;
-  volume /= applet->track->num_channels;
+    /* select image */
+    n = 4 * volume / 100 + 1;
+    if (n <= 0)
+      n = 1;
+    if (n >= 5)
+      n = 4;
+  }
 
-  n = 4 * volume / (applet->track->max_volume -
-      applet->track->min_volume) + 1;
-  if (n <= 0)
-    n = 1;
-  if (n >= 5)
-    n = 4;
-
-  if ((STATE (n, mute) != applet->state) || force_refresh) {
-    if (mute)
+  if (force_refresh || (STATE (n, mute) != applet->state)) {
+    if (mute) {
       pixbuf = pix[0].pixbuf;
-    else
+    } else {
       pixbuf = pix[n].pixbuf;
+    }
 
     gtk_image_set_from_pixbuf (applet->image, pixbuf);
-
     applet->state = STATE (n, mute);
   }
 
+  if (!applet->mixer)
+    return;
+
+  /* build names of selecter tracks */
+  track_names = g_string_new ("");
+  for (iter = g_list_first (applet->tracks); iter; iter = iter->next) {
+    GstMixerTrack *track = iter->data;
+
+    if (iter->next != NULL)
+      g_string_append_printf (track_names, "%s / ", track->label);
+    else
+      track_names = g_string_append (track_names, track->label);
+  }
+
+  if (mute) {
+    tooltip_str = g_strdup_printf (_("%s: muted"), track_names->str);
+  } else {
+    /* Translator comment: I'm not all too sure if this makes sense
+     * to mark as a translation, but anyway. The string is a list of
+     * selected tracks, the number is the volume in percent. You
+     * most likely want to keep this as-is. */
+    tooltip_str = g_strdup_printf (_("%s: %d%%"), track_names->str, (int) volume);
+  }
+  g_string_free (track_names, TRUE);
+
+  gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet),
+			tooltip_str, NULL);
+  g_free (tooltip_str);
+
   applet->lock = TRUE;
-  if (orig_vol > 0)
+  if (volume != 0)
     gtk_range_set_value (applet->dock->scale, volume);
   applet->lock = FALSE;
 
@@ -984,9 +1127,11 @@ cb_gconf (GConfClient *client,
   GConfValue *value;
   const gchar *str, *key;
   const GList *item;
-  GstMixerTrack *active_track = NULL;
   gboolean newdevice = FALSE;
   gchar *keyroot;
+  GList *active_tracks;
+
+  active_tracks = NULL;
 
   keyroot = panel_applet_gconf_get_full_key (PANEL_APPLET (applet), "");
   key = gconf_entry_get_key (entry);
@@ -1006,68 +1151,58 @@ cb_gconf (GConfClient *client,
 					       "gnome-volume-applet-name");
 
         if (!strcmp (cur_el_str, str)) {
-          GstElement *old_element = GST_ELEMENT (applet->mixer);
+          GstElement *old_element = GST_ELEMENT (applet->mixer),
+		     *new_element = item->data;
 
-          /* change element */
-          if (gst_element_set_state (item->data,
-				GST_STATE_READY) != GST_STATE_SUCCESS)
-            continue;
-          gst_object_replace ((GstObject **) &applet->mixer, item->data);
-          gst_element_set_state (old_element, GST_STATE_NULL);
-
-          newdevice = TRUE;
-          if (gst_mixer_list_tracks (applet->mixer)) {
-            active_track = gst_mixer_list_tracks (applet->mixer)->data;
+          if (new_element != old_element) {
+            /* change element */
+            if (gst_element_set_state (item->data,
+				       GST_STATE_READY) != GST_STATE_SUCCESS)
+              continue;
+	    
+            /* save */
+            gst_object_replace ((GstObject **) &applet->mixer, item->data);
+            gst_element_set_state (old_element, GST_STATE_NULL);
+            newdevice = TRUE;
           }
-          str = applet->track->label;
           break;
         }
       }
     }
 
     if (!strcmp (key, GNOME_VOLUME_APPLET_KEY_ACTIVE_TRACK) || newdevice) {
-      for (item = gst_mixer_list_tracks (applet->mixer);
-           item != NULL; item = item->next) {
-        GstMixerTrack *track = item->data;
-
-        if (track->num_channels <= 0)
-          continue;
-
-        if (!strcmp (str, track->label)) {
-          active_track = track;
-          break;
-        } else if (newdevice && !active_track &&
-		   GST_MIXER_TRACK_HAS_FLAG (track,
-					     GST_MIXER_TRACK_MASTER)) {
-          active_track = item->data;
-        }
+      if (!active_tracks) {
+        active_tracks = select_tracks (GST_ELEMENT (applet->mixer), str, FALSE);
       }
 
-      if (active_track) {
+      if (active_tracks) {
         GtkObject *adj;
-        gint page;
+	GstMixerTrack *first_track;
+        gint page, percent;
 
-        g_object_unref (G_OBJECT (applet->track));
-        applet->track = active_track;
-        g_object_ref (G_OBJECT (active_track));
+	/* copy the newly created track list over to the main list */
+	g_list_free (applet->tracks);
+	applet->tracks = g_list_copy (active_tracks);
+
+	first_track = g_list_first (active_tracks)->data;
 
         /* dock */
-        page = (applet->track->max_volume - applet->track->min_volume) / 10;
-        adj = gtk_adjustment_new (0, applet->track->min_volume,
-				  applet->track->max_volume,
-				  (page / 5 > 0) ? page / 5 : 1,
-				  page, 0);
+	adj = gtk_adjustment_new (50, 0, 100, 2, 5, 0);
+	gtk_adjustment_set_value (GTK_ADJUSTMENT (adj), 
+				  gnome_volume_applet_get_volume (applet->mixer, 
+								  first_track));
+
         gnome_volume_applet_dock_change (applet->dock,
 					 GTK_ADJUSTMENT (adj));
         g_signal_connect (adj, "value-changed",
 			  G_CALLBACK (cb_volume), applet);
-
+	
         /* if preferences window is open, update */
-        if (applet->prefs) {
+	if (applet->prefs) {
           gnome_volume_applet_preferences_change (
 	      GNOME_VOLUME_APPLET_PREFERENCES (applet->prefs),
-	      applet->mixer, applet->track);
-        }
+	      applet->mixer, applet->tracks);
+	}
       }
     }
   }
@@ -1129,16 +1264,20 @@ cb_verb (BonoboUIComponent *uic,
 		NULL);
 
   } else if (!strcmp (verbname, "Pref")) {
-    if (applet->prefs)
-      return;
+    if (!applet->mixer) {
+      show_no_mixer_dialog (applet);
+    } else {
+      if (applet->prefs)
+        return;
 
-    applet->prefs = gnome_volume_applet_preferences_new (PANEL_APPLET (applet),
-							 applet->elements,
-							 applet->mixer,
-							 applet->track);
-    g_signal_connect (applet->prefs, "destroy",
-		      G_CALLBACK (cb_prefs_destroy), applet);
-    gtk_widget_show (applet->prefs);
+      applet->prefs = gnome_volume_applet_preferences_new (PANEL_APPLET (applet),
+							   applet->elements,
+							   applet->mixer,
+							   applet->tracks);
+      g_signal_connect (applet->prefs, "destroy",
+		        G_CALLBACK (cb_prefs_destroy), applet);
+      gtk_widget_show (applet->prefs);
+    }
   } else {
     g_warning ("Unknown bonobo command '%s'", verbname);
   }
@@ -1153,7 +1292,9 @@ cb_ui_event (BonoboUIComponent *comp,
 {
   GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (data);
 
-  if (!strcmp (verbname, "Mute")) {
+  if (!applet->mixer) {
+    show_no_mixer_dialog (applet);
+  } else if (!strcmp (verbname, "Mute")) {
     /* mute will have a value of 4 without the ? TRUE : FALSE bit... */
     gboolean mute = applet->state & 1,
              want_mute = !strcmp (state_string, "1") ? TRUE : FALSE;
